Welcome to django-plans's documentation!
========================================
Django-plans is a pluggable app for managing pricing plans with quotas and accounts expiration.

.. image:: _static/images/django-plans-1.png
   :align: center



Contents:
---------
.. toctree::
   :maxdepth: 2

   installation
   integration
   settings
   plans
   customize_models
   quota_validators
   plans_change
   plans_expiration
   plans_recurrence
   taxation
   invoicing
   templating
   south
   caveats


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

Developing
----------

Project leader:

* Krzysztof Dorosz <cypreess@gmail.com>

Contributors:

* Victor Safronovich <vsafronovich@gmail.com>
* Dominik Kozaczko <http://dominik.kozaczko.info>
* Petr Dlouhý <petr.dlouhy@email.cz>
* BlenderKit <info@blenderkit.com>

Source code:
https://github.com/cypreess/django-plans

You are very welcome to join the development team of django-plans.
Contribution via github fork and pull requests. Here are some ideas what is needed:

* More tests.
* More precise documentation.
* Documentation proofreading and copyediting.
* Taxation backends for you country/area.
* Translations & Localizations.
* Other then default change plan policies.



..
    Commercial Support
    ==================

    If you're using django-plans in a commercial environment, paid support is available.
    Services offered include:

    * Advice/help with setup and integration.
    * Advice/help with application architecture.
    * Bugfixes in django-plans itself.
    * Features in django-plans itself.

    If you're interested, please contact Krzysztof Dorosz <cypreess@gmail.com>.
